@@ -2,34 +2,55 @@ from __future__ import annotations
 
 from uuid import uuid4
 from typing import (
-    Any, 
-    Callable, 
-    Literal, 
-    NoReturn, 
+    Any,
+    Callable,
+    Literal,
+    NoReturn,
     Dict
 )
 from pathlib import Path
 from asyncio import gather
-from platform import system
-from datetime import datetime
-from subprocess import run
-from contextlib import suppress
-from unicodedata import normalize
 
-from ujson import dumps, loads, dump, load
-from aiohttp import request, ClientResponse
+from ujson import dumps, dump, load
+from aiohttp import request
 from filetype import guess_mime
 from pybase64 import b64encode
 
 from .enum import MediaType
+from .utils import (
+    get_value,
+    words,
+    on_limit,
+    fix_ascii,
+    to_list,
+    one_or_list
+)
+from .dataclass import (
+    Res,
+    Reply,
+    Msg,
+    ChatMsg,
+    Embed,
+    DataUser,
+    DataChat
+)
 from .exceptions import (
+    EmptyCom,
     SmallReasonForBan,
-    InvalidReturn,
     AminoSays
 )
 
+__all__ = [
+    'Req',
+    'User',
+    'File',
+    'Chat',
+    'Community',
+    'My'
+]
+
 ignore_codes = [
-    1628 # Sorry, you cannot pick this member..
+    1628 # Sorry, you cannot pick this member.. | Chat.config
 ]
 headers: dict[str, str] = {'NDCDEVICEID': '0184a516841ba77a5b4648de2cd0dfcb30ea46dbb4e911a6ed122578b14c7b662c59f9a2c83101f5a1'}
 actual_com:  str | None = None
@@ -37,174 +58,140 @@ actual_chat: str | None = None
 bot_id:      str | None = None
 API = 'https://service.narvii.com/api/v1/'
 
-Req_json = Dict[str, Any]
 
-in_win = system() == 'Windows'
-def clear() -> None:
-    run('cls' if in_win else 'clear', shell=True)
-
-def words(s):
-    return s.strip().count(' ')+1
-
-def get_value(
-    d:       Req_json,
-    *k:      str,
-    convert: Any | None = None
-) -> Any | None:
-
-    with suppress(KeyError):
-        tmp = d[k[0]]
-        for i in k[1:]:
-            tmp = tmp[i]
-
-        if convert:
-            return convert(tmp)
-        return tmp
-
-def fix_ascii(s: str) -> str:
-    return normalize('NFKD', s).encode('ASCII', 'ignore').decode().strip()
-
-
-def on_limit(
-    obj:   list[Any],
-    limit: int
-) -> bool:
-    return limit and len(obj) >= limit
-
-
-async def upload_media(file: str) -> str:
-    return (
-        await _req(
-            'post',
-            '/g/s/media/upload',
-            data=await FILE.get(file),
-            need_dumps=False,
-        )
-    )['mediaValue']
-
-async def upload_chat_bg(file: str) -> str:
-    return (
-        await _req(
-            'post',
-            'g/s/media/upload/target/chat-background',
-            data=await FILE.get(file),
-            need_dumps=False,
-        )
-    )['mediaValue']
-
-async def upload_chat_icon(file: str) -> str:
-    return (
-        await _req(
-            'post',
-            'g/s/media/upload/target/chat-cover',
-            data=await FILE.get(file),
-            need_dumps=False,
-        )
-    )['mediaValue']
+class Req:
+    async def new(
+        method:  str,
+        url:     str,
+        **kwargs
+    ) -> Res:
+        """
+        Create a request
 
+        **kwargs are the extra arguments of aiohttp.request
+        """
 
+        async with request(
+            method  = method,
+            url     = url,
+            **kwargs
+        ) as res:
+            return await Res._make(res)
 
 async def _req(
     method:     str,
     url:        str,
-    *,
     data:       dict[str, Any] | None = None,
-    need_dumps: bool                  = True,
-    return_:    str                   = 'json',
-) -> Req_json | str | bytes | ClientResponse:
+    need_dumps: bool                  = True
+) -> Res:
+    """
+    Create a request for the amino api
 
-    async with request(
-        method           = method,
-        url              = API + url,
-        data             = dumps(data) if need_dumps else data,
-        headers          = headers,
-    ) as res:
-        if res.status >= 400 and (j := await res.json(loads=loads))['api:statuscode'] and j['api:statuscode'] not in ignore_codes:
-            print(j, ignore_codes, j not in  ignore_codes)
-            raise AminoSays(f"{j['api:message']}. Code: {j['api:statuscode']}")
-        if return_ == 'json':
-            return await res.json(loads=loads)
-        if return_ == 'text':
-            return await res.text()
-        if return_ == 'file':
-            return await res.read()
-        if return_ == 'aiohttp':
-            return res
-        raise InvalidReturn(return_)
+    Headers are automatically inserted into the request
 
+    #### need_dumps
+    If need use ujson.dumps on the data
+    """
 
-class _Reply:
-    __slots__ = (
-        'icon',
-        'id',
-        'nickname',
-        'uid'
+    res = await Req.new(
+        method  = method,
+        url     = API + url,
+        data    = dumps(data) if need_dumps else data,
+        headers = headers
     )
 
-    def __init__(self, ext):
-        self.icon = ext['replyMessage']['author']['icon']
-        self.id = ext['replyMessageId']
-        self.nickname = ext['replyMessage']['author']['nickname']
-        self.uid = ext['replyMessage']['author']['uid']
+    api_status_code = res.json['api:statuscode']
+
+    if not res.ok and api_status_code and api_status_code not in ignore_codes:
+        raise AminoSays(f"{res.json['api:message']}. Code: {api_status_code}")
+    return res
+
+
+async def upload_media(file: str) -> str:
+    """
+    Send a file to be used when posting a blog
+
+    Returns the file link
+    """
+
+    return (
+        await _req(
+            'post',
+            '/g/s/media/upload',
+            await File.get(file),
+            False,
+        )
+    ).json['mediaValue']
+
+async def upload_chat_bg(file: str) -> str:
+    """
+    Send a file to be used as chat background
+
+    Returns the file link
+    """
+
+    return (
+        await _req(
+            'post',
+            'g/s/media/upload/target/chat-background',
+            await File.get(file),
+            False,
+        )
+    ).json['mediaValue']
+
+async def upload_chat_icon(file: str) -> str:
+    """
+    Send a file to be used as chat icon
+
+    Returns the file link
+    """
+
+    return (
+        await _req(
+            'post',
+            'g/s/media/upload/target/chat-cover',
+            await File.get(file),
+            False,
+        )
+    ).json['mediaValue']
+
 
 class Message:
-    __slots__ = (
-        'author',
-        'chat',
-        'com',
-        'extensions',
-        'file_link',
-        'icon',
-        'id',
-        'reply',
-        'media_type',
-        'mentioned_users',
-        'nickname',
-        'text',
-        'type',
-        'uid'
-    )
-
-    def from_ws(self, j: Req_json) -> Message:
-        _cm: dict[str, Any] = j['chatMessage']
+    def from_ws(self, j: Dict[str, Any]) -> Msg:
+        """
+        Returns a Msg containing the information from the websocket message
+        
+        Update actual_com and actual_chat with the chat and community of the message received
+        """
 
         global actual_chat, actual_com
-        self.chat: str | None = get_value(_cm, 'threadId', convert=str)
-        self.com:  str | None = get_value(j, 'ndcId', convert=str)
 
-        actual_chat = self.chat
-        actual_com  = self.com
+        actual_chat = get_value(j, 'chatMessage', 'threadId', convert=str)
+        actual_com  = get_value(j, 'ndcId', convert=str)
 
-        self.extensions:  dict[str, Any] | None = get_value(_cm, 'extensions')
-        self.file_link:   str | None            = get_value(_cm, 'mediaValue')
+        return Msg._make(j)
 
-        self.icon:            str | None       = get_value(_cm, 'author', 'icon')
-        self.id:              str | None       = get_value(_cm, 'messageId')
-        self.reply:           _Reply           = _Reply(self.extensions) if 'replyMessage' in self.extensions else None
-        self.media_type:      str | None       = get_value(_cm, 'mediaType')
-        self.mentioned_users: list[str] | None = [u['uid'] for u in get_value(self.extensions, 'mentionedArray') or []]
+    def from_chat(self, j: Dict[str, Any]) -> ChatMsg:
+        """
+        Returns a ChatMsg containing information from Chat.messages messages
+        """
 
-        self.nickname: str | None = get_value(_cm, 'author', 'nickname')
-        self.text:     str | None = get_value(_cm, 'content')
-        self.type:     str | None = get_value(_cm, 'type')
-        self.uid:      str | None = get_value(_cm, 'uid')
-
-        return self
-
-    def from_chat(self, j: Req_json) -> Message:
-        self.author:      User | None           = User(get_value(j, 'author'))
-        self.chat:        str  | None           = get_value(j, 'threadId')
-        self.extensions:  dict[str, Any] | None = get_value(j, 'extensions')
-
-        self.id:              str | None        = get_value(j, 'messageId')
-        self.mentioned_users: list[str] | None  = [u['uid'] for u in get_value(self.extensions, 'mentionedArray') or []]
-        self.text: str | None = get_value(j, 'content')
-        self.type: str | None = get_value(j, 'type')
-
-        return self
+        return ChatMsg._make(j)
 
     class _CreateData:
-        async def msg(type, msgs, reply):
+        """
+        Stores methods for creating Message.send data
+        """
+
+        async def msg(
+            type:  int,
+            msgs:  list[str],
+            reply: Reply
+        ) -> list[Dict[str, Any]]:
+            """
+            Creates the data for sending a message
+            """
+
             return [
                 {'type': type, 'content': i, 'replyMessageId': reply}
                 if reply
@@ -212,10 +199,18 @@ class Message:
                 for i in msgs
             ]
 
-        async def file(files):
-            return [await FILE.process(i) for i in files]
+        async def file(files: list[str | bytes]) -> list[Dict[str, Any]]:
+            """
+            Creates the data for sending a file
+            """
+
+            return [await File.process(i) for i in files]
+
+        async def embed(embed: Embed) -> list[Dict[str, Any]]:
+            """
+            Creates the data for sending a embed
+            """
 
-        async def embed(embed: Embed):
             if embed.image:
                 embed.image = [[100, await upload_media(embed.image), None]]
             return [
@@ -239,11 +234,18 @@ class Message:
         reply: str   | None             = None,
         com:   str   | None             = None,
         chat:  str   | None             = None,
-    ) -> list[Req_json]:
+    ) -> Res | list[Res]:
+        """
+        Send a message, file, embed or reply
 
-        com = com or actual_com
-        chat = chat or actual_chat
-        files = [files] if files and not isinstance(files, (tuple, list)) else files
+        #### reply
+
+        Message id to reply
+        """
+
+        com   = com or actual_com
+        chat  = chat or actual_chat
+        files = to_list(files)
 
         if msgs:
             data = await self._CreateData.msg(type_, msgs, reply)
@@ -252,133 +254,79 @@ class Message:
         else:
             data = await self._CreateData.embed(embed)
 
-        async def foo(i: msgs | files | list[Embed]) -> _req:
+        async def foo(i) -> Res:
             return await _req(
                 'post',
                 f'x{com}/s/chat/thread/{chat}/message',
                 data=i
             )
 
-        return await gather(*[foo(i) for i in data])
-
-
-class Embed:
-    __slots__ = (
-        'msg_text',
-        'title',
-        'text',
-        'link',
-        'image'
-    )
-
-    def __init__(
-        self,
-        msg_text: str,
-        title:    str,
-        text:     str,
-        link:     str,
-        image:    str | bytes = None
-    ):
-        self.msg_text = msg_text
-        self.title    = title
-        self.text     = text
-        self.link     = link
-        self.image    = image
+        return one_or_list(await gather(*[foo(i) for i in data]))
 
 
 class User:
-    __slots__ = (
-        'bio',
-        'blogs_count',
-        'com',
-        'comments_count',
-        'created_time',
-        'followers_count',
-        'following_count',
-        'id',
-        'im_following',
-        'is_online',
-        'level',
-        'nickname',
-        'posts_count',
-        'reputation',
-        'role',
-        'visitors_count',
-    )
-
-    def __init__(self, j: Req_json | None = None):
-        if j:
-            self.bio:             str | None = get_value(j, 'content')
-            self.blogs_count:     int | None = get_value(j, 'blogsCount')
-            self.com:             str | None = get_value(j, 'ndcId', convert=str)
-            self.comments_count:  int | None = get_value(j, 'commentsCount')
-            self.created_time:    int | None = int(datetime.fromisoformat(j['createdTime'][:-1]).timestamp()) if j['createdTime'] else None
-            self.followers_count: str | None = get_value(j, 'membersCount')
-            self.following_count: str | None = get_value(j, 'joinedCount')
-            self.im_following:    bool       = get_value(j, 'followingStatus') == 1
-            self.level:           str | None = get_value(j, 'level')
-            self.nickname:        str | None = get_value(j, 'nickname')
-            self.posts_count:     int | None = get_value(j, 'postsCount')
-            self.id:              str | None = get_value(j, 'uid')
-            self.reputation:      int | None = get_value(j, 'reputation')
-            self.role:            str | None = {0: 'member', 101: 'curator', 100: 'leader', 102: 'leader-agent'}[j['role']]
-            self.visitors_count:  int | None = get_value(j, 'visitoresCount')
-
-    @classmethod
     async def search(
-        cls,
         uids: str | list[str],
         com:  str | None = None
-    ) -> list[User]:
+    ) -> DataUser | list[DataUser]:
+        """
+        Get profile information for a community user
+        """
 
         com = com or actual_com
-        uids = [uids] if not isinstance(uids, (list, tuple)) else uids
+        uids = to_list(uids)
 
-        async def foo(uid: str) -> User:
-            return cls(
-                (await _req('get', f'x{com}/s/user-profile/{uid}'))['userProfile']
-            )
+        async def foo(uid: str) -> DataUser:
+            return DataUser._make((await _req('get', f'x{com}/s/user-profile/{uid}')).json['userProfile'])
 
-        return await gather(*[foo(uid) for uid in uids])
+        return one_or_list(await gather(*[foo(uid) for uid in uids]))
 
     async def ban(
-        self,
         uid:    str,
         *,
         reason: str,
         com:    str | None = None
-    ) -> Req_json:
+    ) -> Res:
+        """
+        Ban a user
+        """
 
-        com = com or actual_com
         if words(reason) < 3:
             raise SmallReasonForBan('Put a reason with at least three words')
 
         return await _req(
             'post',
-            f'x{com}/s/user-profile/{uid}/ban',
+            f'x{com or actual_com}/s/user-profile/{uid}/ban',
             data={'reasonType': 200, 'note': {'content': reason}},
         )
 
     async def unban(
-        self,
         uid:    str,
         *,
         reason: str        = '',
         com:    str | None = None
-    ) -> Req_json:
-
-        com = com or actual_com
+    ) -> Res:
+        """
+        Unban a user
+        """
 
         return await _req(
             'post',
-            f'x{com}/s/user-profile/{uid}/unban',
+            f'x{com or actual_com}/s/user-profile/{uid}/unban',
             data={'note': {'content': reason}} if reason else None,
         )
 
 
 class File:
-    @staticmethod
+    """
+    Stores methods for handling a file
+    """
+
     def type(file: str | bytes) -> Literal[MediaType.LINK, MediaType.BYTES, MediaType.PATH]:
+        """
+        Checks whether the file is a link, bytes or path
+        """
+
         if isinstance(file, str) and file.startswith('http'):
             return MediaType.LINK
 
@@ -387,8 +335,13 @@ class File:
 
         return MediaType.PATH
 
-    @staticmethod
     async def get(file: str | bytes) -> bytes:
+        """
+        Returns the bytes of a file
+
+        If the file is a link, download the file
+        """
+
         type = File.type(file)
 
         if type == MediaType.LINK:
@@ -401,19 +354,26 @@ class File:
         with open(file, 'rb') as f:
             return f.read()
 
-    @staticmethod
     def b64(file_bytes: bytes) -> str:
+        """
+        Convert bytes to base64
+        """
+
         return b64encode(file_bytes).decode()
 
-    async def process(self, file: str | bytes) -> dict[str, Any] | NoReturn:
+    async def process(file: str | bytes) -> dict[str, Any] | NoReturn:
+        """
+        Returns the data to be used Message.send
+        """
+
         if (
-            self.type(file) not in (MediaType.LINK, MediaType.BYTES)
+            File.type(file) not in (MediaType.LINK, MediaType.BYTES)
             and not Path(file).exists()
         ):
             raise FileNotFoundError(file)
 
-        b = await self.get(file)
-        b64 = self.b64(b)
+        b = await File.get(file)
+        b64 = File.b64(b)
         type = (guess_mime(b) or 'audio/mp3').split('/')
 
         if type[-1] == 'gif':
@@ -441,67 +401,47 @@ class File:
 
 
 class Chat:
-    __slots__ = (
-        'announcement',
-        'bg',
-        'can_send_coins',
-        'co_hosts',
-        'created_time',
-        'adm',
-        'extensions',
-        'icon',
-        'id',
-        'is_pinned',
-        'is_private',
-        'members_can_invite',
-        'name',
-        'only_fans',
-        'only_view',
-        'text'
-    )
-
-    def __init__(self, j=None):
-        if j:
-            t:                       Dict[str, Any] | None = get_value(j, 'thread') or j
-            self.extensions:         Dict[str, Any] | None = get_value(t, 'extensions')
-
-            self.announcement:       str | None = get_value(self.extensions, 'announcement') or ''
-            self.bg:                 str | None = get_value(self.extensions, 'bm')[1] if 'bm' in self.extensions else None
-            self.can_send_coins:     bool       = get_value(t, 'tipInfo', 'tippable')
-            self.co_hosts:           list[str]  = get_value(self.extensions, 'coHost') or []
-            self.created_time:       int | None = int(datetime.fromisoformat(t['createdTime'][:-1]).timestamp()) if t['createdTime'] else None
-            self.adm:                str | None = get_value(t, 'author', 'uid')
-            self.icon:               str | None = get_value(t, 'icon')
-            self.id:                 str | None = get_value(t, 'threadId')
-            self.is_pinned:          bool       = get_value(t, 'isPinned')
-            self.is_private:         bool       = get_value(t, 'membersQuota') == 2
-            self.members_can_invite: bool       = get_value(t, 'membersCanInvite') or True
-            self.name:               str | None = get_value(t, 'title')
-            self.only_fans:          bool       = get_value(self.extensions, 'fansOnly')
-            self.only_view:          bool       = get_value(self.extensions, 'viewOnly') or False
-            self.text:               str | None = get_value(t, 'content') or ''
-
-    @classmethod
     async def search(
-        cls,
         com:  str | None = None,
         chat: str | None = None
-    ) -> Chat:
+    ) -> DataChat:
+        """
+        Search for chat information
+        """
 
-        com = com or actual_com
-        chat = chat or actual_chat
-
-        return cls(await _req('get',f'x{com}/s/chat/thread/{chat}'))
+        return DataChat._make((await _req('get', f'x{com or actual_com}/s/chat/thread/{chat or actual_chat}')).json)
 
     async def messages(
-        self,
-        *,
-        check: Callable[[Message], bool] = lambda _: True,
-        com:   str | None = None,
-        chat:  str | None = None,
+        check: Callable[[ChatMsg], bool] = lambda _: True,
         start: int | None = None,
         end:   int | None = None,
-    ) -> list[Message.from_chat]:
+        com:   str | None = None,
+        chat:  str | None = None,
+    ) -> list[ChatMsg]:
+        """
+        Returns a list containing the most recent to the oldest messages in a chat
+
+        ### check
+        ```
+        def check(m: ChatMsg):
+            return m.level > 8
+
+        await Chat.messages(check=check)
+        ```
+
+        Get all messages from people with a level > 8
+
+        ### start, end
+        ```
+        msgs = (await Chat.messages())[10: 100]
+            
+        msgs = await Chat.messages(start=10, end=100)
+        ```
+
+        The two are the same, the advantage of the second way is that the first gets all the messages and then gets the 10-100 messages
+
+        The second gets only 10-100 messages instead of getting all, it is faster
+        """
 
         com = com or actual_com
         chat = chat or actual_chat
@@ -511,9 +451,9 @@ class Chat:
             'get',
             f'x{com}/s/chat/thread/{chat}/message?v=2&pagingType=t&size=100',
         )
-        token = res['paging']['nextPageToken']
-        for msg_ in res['messageList']:
-            if check(msg := Message().from_chat(msg_)):
+        token = res.json['paging']['nextPageToken']
+        for msg_ in res.json['messageList']:
+            if check(msg := MESSAGE.from_chat(msg_)):
                 messages.append(msg)
 
         while True:
@@ -521,37 +461,57 @@ class Chat:
                 'get',
                 f'x{com}/s/chat/thread/{chat}/message?v=2&pagingType=t&pageToken={token}&size=100',
             )
-            for msg in res['messageList']:
-                if check(msg := Message().from_chat(msg)):
+            for msg in res.json['messageList']:
+                if check(msg := MESSAGE.from_chat(msg)):
                     messages.append(msg)
 
             if on_limit(messages, end):
                 break
 
             try:
-                token = res['paging']['nextPageToken']
+                token = res.json['paging']['nextPageToken']
             except KeyError:
                 break
 
         return messages[start:end]
 
     async def clear(
-        self,
         msgs:  str | list[str] | None = None,
-        check: Callable[[Message], bool] = lambda _: True,
+        check: Callable[[ChatMsg], bool] = lambda _: True,
         com:   str | None = None,
         chat:  str | None = None,
         start: int | None = None,
         end:   int | None = None,
-    ) -> list[Req_json]:
+    ) -> Res | list[Res]:
+        """
+        Delete chat messages
+
+        ## If msgs == None, it will delete all chat messages
+
+        ### msgs
+        Message ids to be deleted
+
+        ### check
+        ```
+        def check(m: ChatMsg):
+            return m.level > 8
+
+        await Chat.messages(check=check)
+        ```
+
+        Delete all messages from people with a level > 8
+
+        ### start, end
+        Explanation in Chat.message
+        """
 
         com = com or actual_com
         chat = chat or actual_chat
         msgs = (
-            ([msgs] if not isinstance(msgs, (tuple, list)) else msgs)
+            to_list(msgs)
             if msgs
             else [
-                msg.id for msg in await self.messages(
+                msg.id for msg in await Chat.messages(
                     check=check, com=com, chat=chat, start=start, end=end
                 )
             ]
@@ -564,16 +524,39 @@ class Chat:
                 data={'adminOpName': 102},
             )
 
-        return await gather(*[foo(msg) for msg in msgs])
+        return one_or_list(await gather(*[foo(msg) for msg in msgs]))
 
     async def members(
-        self,
-        check: Callable[[Message], bool] = lambda _: True,
+        check: Callable[[DataUser], bool] = lambda _: True,
         com:   str | None = None,
         chat:  str | None = None,
         start: int | None = None,
         end:   int | None = None,
-    ) -> list[User]:
+    ) -> list[DataUser]:
+        """
+        Returns members of a chat
+
+        ### check
+        ```
+        def check(m: DataUser):
+            return 'L' in m.nickname 
+
+        await Chat.members(check=check)
+        ```
+
+        Get all members that have 'L' in the nickname
+
+        ### start, end
+        ```
+        msgs = (await Chat.members())[10: 100]
+            
+        msgs = await Chat.members(start=10, end=100)
+        ```
+
+        The two are the same, the advantage of the second way is that the first gets all the members and then gets the 10-100 members
+
+        The second gets only 10-100 members instead of getting all, it is faster
+        """
 
         com = com or actual_com
         chat = chat or actual_chat
@@ -585,14 +568,14 @@ class Chat:
             )
             return [
                 i for i in [
-                    User(i) for i in res['memberList'] if res['memberList']
+                    DataUser._make(i) for i in res.json['memberList'] if res.json['memberList']
                 ]
                 if check(i)
             ]
 
         members_count = (await _req(
             'get', f'x{com}/s/chat/thread/{chat}'
-        ))['thread']['membersCount']
+        )).json['thread']['membersCount']
 
         MAX_MEMBERS_COUNT_IN_CHAT = 1000
         return (
@@ -605,39 +588,36 @@ class Chat:
         )[0][start:end]
 
     async def join(
-        self,
-        chat: str, 
-        com: str | None = None
-    ) -> Req_json:
-
-        com = com or actual_com
-        chat = [chat] if not isinstance(chat, (list, tuple)) else chat
+        chats: str | list[str],
+        com:   str | None = None
+    ) -> Res | list[Res]:
+        """
+        Enter a chat
+        """
 
         async def foo(i):
             return await _req(
-                'post', f'x{com}/s/chat/thread/{i}/member/{bot_id}'
+                'post', f'x{com or actual_com}/s/chat/thread/{i}/member/{bot_id}'
             )
 
-        return await gather(*[foo(i) for i in chat])
+        return one_or_list(await gather(*[foo(i) for i in to_list(chats)]))
 
     async def leave(
-        self,
-        chat: str,
-        com: str | None = None
-    ) -> Req_json:
-
-        com = com or actual_com
-        chat = [chat] if not isinstance(chat, (list, tuple)) else chat
+        chats: str | list[str],
+        com:   str | None = None
+    ) -> Res | list[Res]:
+        """
+        Leave a chat
+        """
 
         async def foo(i):
             return await _req(
-                'delete', f'x{com}/s/chat/thread/{i}/member/{bot_id}'
+                'delete', f'x{com or actual_com}/s/chat/thread/{i}/member/{bot_id}'
             )
 
-        return await gather(*[foo(i) for i in chat])
+        return one_or_list(await gather(*[foo(i) for i in to_list(chats)]))
 
     async def create(
-        self,
         name:           str,
         text:           str | None  = None,
         bg:             str | bytes = None,
@@ -645,9 +625,10 @@ class Chat:
         only_fans:      bool        = False,
         invite_members: list[str]   = [],
         com:            str | None  = None
-    ) -> Req_json:
-
-        com = com or actual_com
+    ) -> Res:
+        """
+        Create a chat
+        """
 
         img = [100, await upload_chat_bg(bg), None] if bg else bg
         data = {
@@ -666,38 +647,39 @@ class Chat:
             'eventSource': 'GlobalComposeMenu'
         }
 
-        return await _req('post', f'x{com}/s/chat/thread', data=data)
+        return await _req('post', f'x{com or actual_com}/s/chat/thread', data=data)
 
     async def delete(
-        self,
         com:  str | None = None,
         chat: str | None = None
-    ) -> bool:
+    ) -> Res:
+        """
+        Delete a chat
+        """
 
-        com = com or actual_com
-        chat = chat or actual_chat
+        return await _req('delete', f'x{com or actual_com}/s/chat/thread/{chat or actual_chat}')
 
-        return (await _req('delete', f'x{com}/s/chat/thread/{chat}', return_='aiohttp')).ok
-
-    async def config(
-        self,
-        name:               str | None         = None,
-        text:               str | None         = None,
-        bg:                 str | bytes | None = None,
-        pin:                bool | None        = None,
-        announcement:       str | None         = None,
-        only_view:          bool | None        = None,
-        members_can_invite: bool | None        = None,
-        can_send_coins:     bool | None        = None,
-        change_adm_to:      str | None         = None,
-        com:                str | None         = None,
-        chat:               str | None         = None
+    async def edit(
+        name:               str  | None         = None,
+        text:               str  | None         = None,
+        bg:                 str  | bytes | None = None,
+        pin:                bool | None         = None,
+        announcement:       str  | None         = None,
+        only_view:          bool | None         = None,
+        members_can_invite: bool | None         = None,
+        can_send_coins:     bool | None         = None,
+        change_adm_to:      str  | None         = None,
+        com:                str  | None         = None,
+        chat:               str  | None         = None
     ) -> None:
+        """
+        Edit a chat
+        """
 
         com = com or actual_com
         chat = chat or actual_chat
 
-        info = await self.search(chat=chat)
+        info = await Chat.search(chat=chat)
         if name or text:
             data = {
                 'extensions': {
@@ -716,7 +698,7 @@ class Chat:
 
 
         if bg:
-            await _req('post', f'x{com}/s/chat/thread/{chat}/member/{bot_id}/background', data=await FILE.process(bg))
+            await _req('post', f'x{com}/s/chat/thread/{chat}/member/{bot_id}/background', data=await File.process(bg))
         elif bg == False:
             await _req('delete', f'x{com}/s/chat/thread/{chat}/member/{bot_id}/background')
 
@@ -749,23 +731,31 @@ class Chat:
             await _req('post', f'x{com}/s/chat/thread/{chat}/transfer-organizer', data={'uidList': [change_adm_to]})
 
     async def change_co_hosts(
-        self,
         add:    list[str] | str | None = None,
-        remove: str | None = None,
+        remove: list[str] | str | None = None,
         com:    str | None = None,
         chat:   str | None = None
-    ) -> None:
+    ) -> Res | list[Res]:
+        """
+        Add or remove co-hosts
+        """
 
         com = com or actual_com
         chat = chat or actual_chat
-        add = [add] if add and not isinstance(add, (list, tuple)) else add
+        add = to_list(add)
 
         if add:
-            await _req('post', f'x{com}/s/chat/thread/{chat}/co-host', data={'uidList': add})
+            return await _req('post', f'x{com}/s/chat/thread/{chat}/co-host', data={'uidList': add})
         elif remove:
-            await _req('delete', f'x{com}/s/chat/thread/{chat}/co-host/{remove}')
+            async def foo(i):
+                return await _req('delete', f'x{com}/s/chat/thread/{chat}/co-host/{i}')
+            return one_or_list(await gather(*[foo(i) for i in remove]))
+
+    async def save(filename: str | None = None) -> None:
+        """
+        Saves all information from a chat to a .json
+        """
 
-    async def save(self, filename: str | None = None) -> None:
         chat = await Chat.search()
         info = {
             'name': chat.name,
@@ -784,7 +774,7 @@ class Chat:
             'only_view': chat.only_view,
             'only_fans': chat.only_fans,
 
-            'members': [i.id for i in await self.members()]
+            'members': [i.id for i in await Chat.members()]
         }
 
         n = 0
@@ -793,25 +783,32 @@ class Chat:
         with open(filename or f'{n}.json', 'w') as f:
             dump(info, f, indent=4, escape_forward_slashes=False)
 
-    async def load(self, filename: str) -> None:
+    async def load(filename: str) -> None:
+        """
+        Creates a chat containing the .json information created by Chat.save
+
+        The name will be a uuid4 in the beginning for the program to identify the chat that was created,
+        after that it will change to the correct name
+        """
+
         with open(filename, 'r') as f:
             f = load(f)
 
         tmp_chat_name = str(uuid4())
-        await self.create(
-            name = tmp_chat_name,
-            text = f['text'],
-            bg = f['bg'],
-            icon = f['icon'],
-            only_fans= f['only_fans'],
-            invite_members=f['members']
+        await Chat.create(
+            name           = tmp_chat_name,
+            text           = f['text'],
+            bg             = f['bg'],
+            icon           = f['icon'],
+            only_fans      = f['only_fans'],
+            invite_members = f['members']
         )
 
         chats = list((await Community.chats()).values())[0]
         names = [i.name for i in chats]
-        ids = [i.id for i in chats]
+        ids   = [i.id for i in chats]
 
-        await self.config(
+        await Chat.edit(
             name               = f['name'],
             pin                = f['is_pinned'],
             announcement       = f['announcement'],
@@ -822,27 +819,32 @@ class Chat:
             chat               = ids[names.index(tmp_chat_name)]
         )
 
-        await self.change_co_hosts(f['co_hosts'])
+        await Chat.change_co_hosts(f['co_hosts'])
 
 class Community:
-    @staticmethod
     async def chats(
         need_print:   bool       = False,
         ignore_ascii: bool       = False,
         com:          str | None = None
-    ) -> dict[str, list[Chat]]:
+    ) -> dict[str, list[DataChat]]:
+        """
+        Returns the chats that you are in the community
 
-        if not actual_com and not com:
-            raise Exception('Enter a com or send a message in a chat')
+        ### need_print
+        Print the chats in a readable form
 
-        com = com or actual_com
-        com = [com] if not isinstance(com, (list, tuple)) else com
+        ### ignore_ascii
+        Removes special characters, which can disrupt the need_print
+        """
+
+        if not (com := to_list(com or actual_com)):
+            raise EmptyCom('Enter a com or send a message in a chat')
 
         async def foo(i):
             res = await _req(
                 'get', f'x{i}/s/chat/thread?type=public-all&start=0&size=100'
             )
-            return {str(i): [Chat(i) for i in res['threadList']]}
+            return {str(i): [{'name': i['title'], 'id': i['threadId']} for i in res.json['threadList']]}
 
         a = await gather(*[foo(i) for i in com])
         chats = {k: v for i in a for k, v in i.items()}
@@ -852,7 +854,7 @@ class Community:
                 max_name = len(
                     max(
                         [
-                            i.name if not ignore_ascii else fix_ascii(i.name)
+                            i['name'] if not ignore_ascii else fix_ascii(i['name'])
                             for i in e
                         ],
                         key=len,
@@ -860,27 +862,47 @@ class Community:
                 )
                 print(i)
                 for n in e:
-                    name = n.name if not ignore_ascii else fix_ascii(n.name)
+                    name = n['name'] if not ignore_ascii else fix_ascii(n['name'])
                     a = max_name - len(name)
-                    print(f"    {name} {' '*a}-> {n.id}")
+                    print(f"    {name} {' '*a}-> {n['id']}")
                 print()
         return chats
 
+    async def staff(com=None) -> Dict[list[Dict[str, str]]]:
+        """
+        Returns a dictionary containing community leaders and curators
+        """
+
+        if not (com := com or actual_com):
+            raise EmptyCom('Enter a com or send a message in a chat')
+
+        leaders  = [{'nickname': i['nickname'], 'uid': i['uid']} for i in (await _req('get', f'x{com}/s/user-profile?type=leaders&start=0&size=100')).json['userProfileList']]
+        curators = [{'nickname': i['nickname'], 'uid': i['uid']} for i in (await _req('get', f'x{com}/s/user-profile?type=curators&start=0&size=100')).json['userProfileList']]
+        return {'leaders': leaders, 'curators': curators}
+
 
 class My:
-    @staticmethod
     async def chats(
         need_print:   bool = True,
         ignore_ascii: bool = False
     ) -> dict[str, list[str, list[str]]]:
+        """
+        Returns chats in which you are from all communities
+
+        ### need_print
+        Print the chats in a readable form
+
+        ### ignore_ascii
+        Removes special characters, which can disrupt the need_print
+        """
 
         res = await _req('get', 'g/s/community/joined?v=1&start=0&size=50')
-        coms = {str(i['ndcId']): [i['name'], []] for i in res['communityList']}
+        coms = {str(i['ndcId']): [i['name'], []] for i in res.json['communityList']}
 
         async def foo(i):
-            return await _req(
+            return (await _req(
                 'get', f'x{i}/s/chat/thread?type=joined-me&start=0&size=100'
-            )
+            )).json
 
         chats = await gather(*[foo(i) for i in coms])
 
@@ -915,18 +937,26 @@ class My:
 
         return coms
 
-    @staticmethod
     async def communities(
         need_print:   bool = True,
         ignore_ascii: bool = False
     ) -> dict[str, str]:
+        """
+        Returns all the communities you are in
 
-        res = await _req('get', f'g/s/community/joined?v=1&start=0&size=50')
+        ### need_print
+        Print the chats in a readable form
+
+        ### ignore_ascii
+        Removes special characters, which can disrupt the need_print
+        """
+
+        res = await _req('get', f'g/s/community/joined?v=1&start=0&size=100')
         coms = {
             i['name']
             if not ignore_ascii
             else fix_ascii(i['name']): str(i['ndcId'])
-            for i in res['communityList']
+            for i in res.json['communityList']
         }
 
         if need_print:
@@ -942,5 +972,4 @@ class My:
 #   Cache   #
 # # # # # # #
 
-FILE    = File()
 MESSAGE = Message()
